@@ -43,10 +43,12 @@ setMethod("is.editor", "PermissionTuple", function (x) {
 #' @param notify logical: should users who are getting new privileges on this
 #' dataset be sent an email informing them of this fact? Default is
 #' \code{TRUE}.
+#' @param message character: what message should users who are getting notified
+#' about new permissions on this dataset receive?
 #' @return Invisibly, the dataset.
 #' @seealso \code{\link{unshare}}
 #' @export
-share <- function (dataset, users, edit=FALSE, notify=TRUE) {
+share <- function (dataset, users, edit=FALSE, notify=TRUE, message=NULL) {
     perms <- permissions(dataset)
     if (length(edit) == 1) {
         edit <- rep(edit, length(users))
@@ -54,11 +56,15 @@ share <- function (dataset, users, edit=FALSE, notify=TRUE) {
     if (length(edit) != length(users)) {
         halt("Must supply `edit` permissions of equal length as the number of `emails` supplied")
     }
+    if (!is.null(message) && !notify) {
+        halt("Cannot send message if not notifying")
+    }
     payload <- lapply(edit,
         function (e) list(dataset_permissions=list(edit=e, view=TRUE)))
     names(payload) <- users
     payload$send_notification <- notify
     if (notify) {
+        payload$message <- message
         payload$url_base <- passwordSetURLTemplate()
         payload$dataset_url <- webURL(dataset)
     }
