@@ -48,6 +48,15 @@ setIndexSlot <- function (x, i, value, unique=FALSE) {
     return(x)
 }
 
+setIndexSlotOnEntity <- function (x, i, value, ...) {
+    ## For catalog setters where you can't PATCH the catalog
+    old <- getIndexSlot(x, i, ...)
+    changes <- dirtyElements(old, value)
+    mapply(function (m, v) setEntitySlot(m, i, v),
+        m=x[changes], v=value[changes])
+    return(refresh(x))
+}
+
 dirtyElements <- function (x, y) {
     !mapply(identical, x, y, USE.NAMES=FALSE, SIMPLIFY=TRUE)
 }
@@ -89,9 +98,25 @@ setMethod("[", c("ShojiCatalog", "ANY"), function (x, i, ...) {
 #' @rdname catalog-extract
 #' @export
 setMethod("[[", c("ShojiCatalog", "ANY"), function (x, i, ...) {
+    ## Note that this returns a bare list, not an IndexTuple
     index(x)[[i]]
 })
 
+getTuple <- function (x, i, Constructor=ShojiTuple, ...) {
+    b <- index(x)[[i]]
+    if (is.null(b)) return(NULL)
+    Constructor(index_url=self(x), entity_url=urls(x)[i], body=b)
+}
+
+getEntity <- function (x, i, Constructor=ShojiEntity, ...) {
+    stopifnot(length(i) == 1)
+    url <- urls(x)[i]
+    if (is.na(url)) {
+        halt("subscript out of bounds: ", i)
+    }
+    return(Constructor(crGET(url)))
+}
+
 #' @rdname catalog-extract
 #' @export
 setMethod("[[", c("ShojiCatalog", "character"), function (x, i, ...) {
@@ -100,7 +125,7 @@ setMethod("[[", c("ShojiCatalog", "character"), function (x, i, ...) {
     if (is.na(w)) {
         return(NULL)
     }
-    index(x)[[w]]
+    return(x[[w]])
 })
 
 #' @rdname catalog-extract
