@@ -91,6 +91,10 @@ setMethod("delete", "ShojiTuple", function (x, ...) {
 #' @rdname tuple-methods
 #' @export
 setMethod("delete", "DatasetTuple", function (x, confirm=requireConsent(), ...) {
+    if (!missing(confirm)) {
+        warning("The 'confirm' argument is deprecated. See ?with_consent.",
+            call.=FALSE)
+    }
     prompt <- paste0("Really delete dataset ", dQuote(name(x)), "?")
     if (confirm && !askForPermission(prompt)) {
         halt("Must confirm deleting dataset")
