@@ -24,22 +24,24 @@ with_test_authentication({
             expect_output(batches(part1),
                 get_output(data.frame(id=c(0, 1),
                 status=c("imported", "imported"))))
-            expect_error(
-                expect_message(part1 <- appendDataset(part1, part2),
-                    "Result URL"),
-                "Variable is array in one dataset and not the other")
+
+            expect_message(
+                expect_error(part1 <- appendDataset(part1, part2),
+                    "Variable is array in one dataset and not the other"),
+                NA) ## No Result URL printed because autorollback=TRUE
+
             part1 <- refresh(part1)
             expect_output(batches(part1),
                 get_output(data.frame(id=c(0, 1),
                 status=c("imported", "imported"))))
         })
         test_that("The append fails and reports conflict on type mismatch", {
-            expect_error(
-                expect_message(appendDataset(part1, part2, autorollback=FALSE),
-                    "Result URL"),
-                "Variable is array in one dataset and not the other")
+            expect_message(
+                expect_error(appendDataset(part1, part2, autorollback=FALSE),
+                    "Variable is array in one dataset and not the other"),
+                "Result URL")
         })
-        
+
         part1 <- refresh(part1)
         test_that("There is an 'error' batch, and cleanseBatches purges the errored batch", {
             expect_output(batches(part1),
@@ -62,9 +64,7 @@ with_test_authentication({
             expect_output(summary(comp), "Type mismatch: 1")
         })
         test_that("Append detects text/numeric type mismatch", {
-            expect_error(
-                expect_message(appendDataset(part1, part2),
-                    "Result URL"),
+            expect_error(appendDataset(part1, part2),
                 "Type of 000001 does not match target 000000 and cannot be converted.")
         })
     })
