@@ -12,6 +12,13 @@ with_mock_HTTP({
         expect_length(cats, 3)
     })
 
+    test_that("Categories print method", {
+        expect_output(cats[[1]],
+            get_output(data.frame(id=1, name="Male", value=1, missing=FALSE)))
+        expect_output(cats,
+            get_output(data.frame(id=c(1, 2, -1), name=c("Male", "Female", "No Data"), value=c(1, 2, NA), missing=c(FALSE, FALSE, TRUE))))
+    })
+
     test_that("Categories validation", {
         expect_error(Categories(
             list(id=-1L, name="B", numeric_value=1L, missing=FALSE),
@@ -227,7 +234,7 @@ with_mock_HTTP({
 
 
 with_test_authentication({
-    describe("When editing categories", {
+    whereas("When editing categories", {
         ds <- newDataset(df[,4,drop=FALSE])
         test_that("categories setters persist to the server", {
             expect_equal(names(categories(ds$v4)), c("B", "C", "No Data"))
@@ -313,7 +320,7 @@ with_test_authentication({
         })
     })
 
-    describe("When manipulating categories of array variables", {
+    whereas("When manipulating categories of array variables", {
         ds <- newDatasetFromFixture("apidocs")
         test_that("dichotomizing dichotomizes the subvariables", {
             expect_true(is.MR(ds$allpets))
